function SelfSupAM_MedicalDiagnosis()
%   SelfSupAM_MedicalDiagnosis.m
%       Exercises Self-Supervised ARTMAP on the 2D medical diagnosis illustration.
%
%   Greg Amis
%   Technology Lab
%   Dept. of Cognitive & Neural Systems
%   Boston University
%   26 March 2009
%
%   Licensing Policy
%   This implementation is made available to the general public under the terms 
%   of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
%   (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
%   As such, it is available free of charge, and may be copied, redistributed, or modified, 
%   as long as any resulting work is distributed under the same terms of
%   Copyleft.

%% Data
overlap = 0.7;
Nstage1 = 50; 
Nstage2 = 10000; 
Ntest   = 5000;
seed = 1833;

rand('state',seed);

%Prep data
[stage1Inputs,stage1Labels] = create_diagnosis_data(Nstage1,overlap);
stage1Inputs(2,:) = NaN; %No shock information
SelfSupAM_loadJava();
stage2Inputs = edu.bu.cns.data.InputsImpl( create_diagnosis_data(Nstage2,overlap)' ); %no labels
[testInputs,testLabels] = create_diagnosis_data(Ntest,overlap);
[ X, Y ] = meshgrid(linspace(0,1,100));
gridInputs = [ X(:), Y(:) ]';

%% Quick run
am = SelfSupAM_trainStage1(stage1Inputs,stage1Labels,'E2',1);
acc1 = 100*mean(SelfSupAM_test(am,testInputs)==testLabels);
disp(sprintf('Accuracy after Stage 1 training: %1.1f%%',acc1));
am.trainStage2( stage2Inputs );
acc2 = 100*mean(SelfSupAM_test(am,testInputs)==testLabels);
disp(sprintf('Accuracy after Stage 2 training: %1.1f%%',acc2));

%% Animation
timeStep = 0.01;

am = SelfSupAM_trainStage1(stage1Inputs,stage1Labels,'E2',1);

f = figure; hold on;
axis square; 
axis( repmat([-0.1 1.1],1,2) );
set(gca,'FontSize',12,...
    'XTick',[ 0 1 ],'XTickLabel','low|high',...
    'YTick',[ 0 1 ],'YTickLabel','none|shock');
xlabel('temperature','FontSize',14,'FontAngle','italic');
ylabel('shock','FontSize',14,'FontAngle','italic');

tic
for n = 0:Nstage2
    
    if ~ishandle(f), break; end;
    
    timeDelta = toc-timeStep*n;
    
    if n==0 || n==Nstage2 || timeDelta<timeStep*10
        %Enough time slack to draw plot
        gridPreds = SelfSupAM_test(am, gridInputs);
        testAccuracy = 100*mean(SelfSupAM_test(am,testInputs)==testLabels);
        cla;
        SelfSupAM_plot2D(am,gridPreds);
        
        if n==0
            title({'Boxes and classification pattern after Stage 1 training';...
                    sprintf('Test Accuracy = %1.1f%%',testAccuracy)},...
                    'FontSize',14,'FontWeight','bold');
        else
            title( { sprintf('After %d Stage 2 points',n);
                    sprintf('Test Accuracy = %1.1f%%',testAccuracy) },...
                    'FontSize',14,'FontWeight','bold');
            a = stage2Inputs.get(n-1).features;
            p = plot(a(1),a(2),'m*','MarkerSize',8);
        end;
        
        drawnow;
        
        if n==0
            pause(1);
            tic;
        elseif timeDelta<0 %too fast
            pause(max(0,timeStep*n-toc));
        end;
        
    end;
    
    if n<Nstage2
        am.trainStage2( stage2Inputs.get(n) );
    end;
    
end; %for n

if ishandle(p)
    delete(p);
end;



