function [model] = SelfSupAM_createInstance( varargin )
%   SelfSupAM_createInstance Creates a new Self-Supervised ARTMAP java model 
%
%   [model] = SelfSupAM_createInstance( 
%        "PropertyName1",propValueel, "PropertyName2",propValuee2,... )
%     Creates a new Self-Supervised ARTMAP java model, using the passed
%     name:value parameter pairs
%     Parameters
%       M ~ Number of input features
%       L ~ Number of output classes
%       V ~ Number of voters (defaults to V=1)
%       classCap ~ Maximum number of points from each class
%       alpha ~ signal rule parameter
%       beta1 ~ Stage 1 learning fraction
%       beta2 ~ Stage 2 learning fraction
%       epsilon ~ match tracking parameter
%       rhobar ~ baseline vigilance
%       p ~ CAM rule power
%       E1 ~ # stage1 training epochs
%       E2 ~ # stage2 training epochs
%
%           
%   Based on:   Amis, G., & Carpenter, G.A. (2009). 
%                   Self-Supervised ARTMAP. (in preparation)
%   
%
%   Greg Amis
%   Technology Lab
%   Dept. of Cognitive & Neural Systems
%   Boston University
%   29 March 2009
%
%   Licensing Policy
%   This implementation is made available to the general public under the terms 
%   of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
%   (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
%   As such, it is available free of charge, and may be copied, redistributed, or modified, 
%   as long as any resulting work is distributed under the same terms of Copyleft.

if mod(nargin,2)~=0
    error('Arguments must be in name:value pair form'); 
end;

ensemble = edu.bu.cns.classifiers.VoterEnsemble();
voter = edu.bu.cns.classifiers.artmap.SelfSupervisedARTMAP();
    
%Fill model with passed args
for i = 1:2:nargin
    if ~ischar(varargin{i})
        error( 'Args must be in the form of key-value pairs.' ); 
    end;
    fieldName = varargin{i};
    fieldName(1) = upper(fieldName(1));
    fieldValue = varargin{i+1};
    setter = sprintf('set%s',fieldName);
    if ismethod(ensemble,setter)
        target = 'ensemble';
    elseif ismethod( voter, setter )
        target = 'voter';
    else
        error('Unknown parameter %s',fieldName);
    end;
    evalStr = sprintf('%s.%s(%g);',target,setter,fieldValue);
    eval(evalStr);   
end;

if ensemble.getV()==1 && ~ensemble.hasClassCap();
    model = voter;
else
    model = ensemble;
    model.setTemplate(voter);
end;


