function preds = SelfSupAM_test( model, inputs )
%   SelfSupAM_test Tests a single Self-Supervised ARTMAP voter.
%
%   preds = SelfSupAM_test( model, inputs ) tests a Self-Supervised ARTMAP voter having
%     the passed long-term memory and params on the passed testing inputs,
%     returning a 1xN vector of label predictions
%       model ~ Java object returned by SelfSupAM_trainStage2
%           Also works with a trained VoterEnsemble object
%       inputs ~ MxN floating point (double|single), 
%           where N is the number of inputs, M is the number of input features,
%           and all values are already normalized to the unit interval,
%           i.e., all(inputs(:)>=0 & inputs(:)<=1)
%
%   Based on:   Amis, G., & Carpenter, G.A. (2009). 
%                   Self-Supervised ARTMAP. (in preparation)
%
%   Greg Amis
%   Technology Lab
%   Dept. of Cognitive & Neural Systems
%   Boston University
%   26 March 2009
%
%   Licensing Policy
%   This implementation is made available to the general public under the terms 
%   of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
%   (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
%   As such, it is available free of charge, and may be copied, redistributed, or modified, 
%   as long as any resulting work is distributed under the same terms of Copyleft.

if nargin~=2, error('Model and inputs required.'); end;

jinputs = edu.bu.cns.data.InputsImpl( inputs' );

preds = model.test(jinputs)' + 1;

