/**
 *	SelfSupervisedClassifier.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Nov 13, 2008
 *
 *  Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft.
 */
package edu.bu.cns.classifiers;

import edu.bu.cns.data.Inputs;
import edu.bu.cns.data.LabeledInputs;

/**
 *	Interface for models that can learn classification patterns from self-supervised training.
 */
public interface SelfSupervisedClassifier extends SupervisedClassifier {
	
	/**
	 * Trains the classifier using the passed labeled inputs
	 * @param labeledInputs
	 */
	public void trainStage1(LabeledInputs labeledInputs);
	
	/**
	 * Trains the classifier using the passed unlabeled inputs
	 * @param inputs
	 */
	public void trainStage2(Inputs<?> inputs);
	
	
	/**
	 * Trains and tests, returning class predictions.
	 *
	 * @param stage1Training
	 * @param stage2Training
	 * @param testInputs
	 * @return class predictions
	 */
	public int[] exercise( LabeledInputs stage1Training, Inputs<?> stage2Training, Inputs<?> testInputs);
	
	/**
	 * Trains and tests, returning class predictions.
	 * 
	 * @param stage1Training
	 * @param stage2Training
	 * @param testInputs
	 * @return class probabilities
	 */
	public float[][] exerciseDistribution( LabeledInputs stage1Training, Inputs<?> stage2Training, Inputs<?> testInputs);
	
	/**
	 * Creates a deep copy of the classifier.
	 * @return
	 */
	public SelfSupervisedClassifier clone();
	
}
