/**
 *	InputFeaturesLengthMismatchException.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Nov 15, 2008
 *
 *  Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft.
 */
package edu.bu.cns.data;

import edu.bu.cns.util.FormattableException;

/**
 *	Thrown when an {@link Input} has a different number of features than expected
 */
public class InputFeaturesLengthMismatchException extends FormattableException {
	
	private static final long serialVersionUID = 3203146454372781335L;

	private InputFeaturesLengthMismatchException( final int inputsLength, final int inputLength)
	{
		super(inputsLength,inputLength);
	}
	
	@Override
	protected String getMsgFmt() {
		return "Expected %d features, but input had %d.";
	}
	
	public static void assertMatchingNumberOfInputs(final int inputsLength, final int inputLength)
	{
		if (inputsLength!=inputLength)
			throw new InputFeaturesLengthMismatchException(inputsLength,inputLength);
	}

}
