/**
 *	DeepCopier.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Aug 2, 2005
 *
 *  Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft.
 */
package edu.bu.cns.util;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * @author gamis
 *
 */
public class DeepCopier {
	
	
	@SuppressWarnings("unchecked")
	public static <T> T createDeepCopy(final T src) {
		ObjectOutputStream oos = null;
		ObjectInputStream ois = null;
		try {
			ByteArrayOutputStream bos = new ByteArrayOutputStream(); 
			oos = new ObjectOutputStream(bos); 
			oos.writeObject(src); 
			oos.flush(); 
			ByteArrayInputStream bin = new ByteArrayInputStream(bos.toByteArray()); 
			ois = new ObjectInputStream(bin); 
			return (T) ois.readObject(); 
		} catch (Exception e) {
			throw new RuntimeException(e);
		} finally {
			try {
				if (oos != null)
					oos.close();
				if (ois != null)
					ois.close();
			} catch (IOException e) {
				throw new RuntimeException(e);
			}
		}
	}

}
